@@ -12,12 +12,13 @@
 from typing import TYPE_CHECKING
 
 from pycatia.system_interfaces.any_object import AnyObject
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 if TYPE_CHECKING:
     from pycatia.drafting_interfaces.drawing_view import DrawingView
     from pycatia.drafting_interfaces.drawing_sheet import DrawingSheet
 
+
 class DrawingComponent(AnyObject):
     """
         .. note::
