@@ -575,7 +575,7 @@ class DrawingDimension(AnyObject):
 
         self.drawing_dimension.ValueReference = value
 
-    def get_boundary_box(self, o_values: tuple) -> None:
+    def get_boundary_box(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -596,11 +596,10 @@ class DrawingDimension(AnyObject):
                 | 
                 |              MyDimension.GetBoundaryBox(oValues)
 
-        :param tuple o_values:
-        :return: None
-        :rtype: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.drawing_dimension.GetBoundaryBox(o_values)
+        return self.drawing_dimension.GetBoundaryBox()
         # # # # Autogenerated comment: 
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -617,7 +616,7 @@ class DrawingDimension(AnyObject):
         # # system_service = self.application.system_service
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_clip(self, x: float, y: float, o_kept_side: int) -> None:
+    def get_clip(self) -> tuple[float, float, int]:
         """
         .. note::
             :class: toggle
@@ -648,13 +647,10 @@ class DrawingDimension(AnyObject):
                 |                MyDimension.GetClip(X, Y, keptSide)
                 |              end if
 
-        :param float x:
-        :param float y:
-        :param int o_kept_side:
-        :return: None
-        :rtype: None
+        :return: tuple[float, float, int]
+        :rtype: tuple
         """
-        return self.drawing_dimension.GetClip(x, y, o_kept_side)
+        return self.drawing_dimension.GetClip()
 
     def get_dim_ext_line(self) -> DrawingDimExtLine:
         """
@@ -710,14 +706,7 @@ class DrawingDimension(AnyObject):
         """
         return DrawingDimLine(self.drawing_dimension.GetDimLine())
 
-    def get_tolerances(self,
-                       o_tol_type: int,
-                       o_tol_name: str,
-                       o_up_tol: str,
-                       o_low_tol: str,
-                       od_up_tol: float,
-                       od_low_tol: float,
-                       o_display_mode: int) -> None:
+    def get_tolerances(self) -> tuple[int, str, str, str, float, float, int]:
         """
         .. note::
             :class: toggle
@@ -756,25 +745,10 @@ class DrawingDimension(AnyObject):
                 |              MyDimension.GetTolerances(oTolType, oTolName, oUpTol, oLowTol,
                 |              odUpTol, odLowTol, oDisplayMode)
 
-        :param int o_tol_type:
-        :param str o_tol_name:
-        :param str o_up_tol:
-        :param str o_low_tol:
-        :param float od_up_tol:
-        :param float od_low_tol:
-        :param int o_display_mode:
-        :return: None
-        :rtype: None
+        :return: tuple(int, str, str, str, float, float, int)
+        :rtype: tuple
         """
-        return self.drawing_dimension.GetTolerances(
-            o_tol_type,
-            o_tol_name,
-            o_up_tol,
-            o_low_tol,
-            od_up_tol,
-            od_low_tol,
-            o_display_mode
-        )
+        return self.drawing_dimension.GetTolerances()
 
     def get_value(self) -> DrawingDimValue:
         """
