@@ -9,7 +9,7 @@
         
 """
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Tuple
 
 from pycatia.drafting_interfaces.drawing_arrows import DrawingArrows
 from pycatia.drafting_interfaces.drawing_components import DrawingComponents
@@ -28,6 +28,7 @@ from pycatia.system_interfaces.any_object import AnyObject
 if TYPE_CHECKING:
     from pycatia.drafting_interfaces.drawing_text import DrawingText
 
+
 class DrawingView(AnyObject):
     """
         .. note::
@@ -1042,32 +1043,32 @@ class DrawingView(AnyObject):
         """
         return self.drawing_view.SetViewName(i_view_name_prefix, i_view_name_ident, i_view_name_suffix)
 
-    def size(self, o_values: tuple) -> float:
+    def size(self) -> Tuple[float, float, float, float]:
         """
         .. note::
             :class: toggle
 
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                 | o Sub Size(CATSafeArrayVariant oValues)
-                | 
+                |
                 |     Returns the bounding box of the drawing view.
                 |     Warning: This method is not available with 2D Layout for 3D
                 |     Design.
-                | 
+                |
                 |     Parameters:
-                | 
+                |
                 |         oValues
                 |             The values of the view bounding box: Xmin, Xmax, Ymin, Ymax
-                |             
-                | 
+                |
+                |
                 |     Example:
-                | 
-                |           
-                | 
+                |
+                |
+                |
                 |              This example gets the bounding box of the ViewToWorkOn drawing
                 |              view.
-                |              
-                | 
+                |
+                |
                 |              Dim oXY(4) As Double
                 |              ViewToWorkOn.Size oXY
                 |              Xmin = oXY(0)
@@ -1079,23 +1080,24 @@ class DrawingView(AnyObject):
         :return: Double
         :rtype: Double
         """
-        # todo: test this
-        return self.drawing_view.Size(o_values)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'size'
-        # # vba_code = """
-        # # Public Function size(drawing_view)
-        # #     Dim oValues (2)
-        # #     drawing_view.Size oValues
-        # #     size = oValues
-        # # End Function
-        # # """
+        vba_function_name = "size"
+        vba_code = """
+        Public Function size(drawing_view)
+            Dim oXY(4)
+            drawing_view.Size oXY
+            size = oXY
+        End Function
+        """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        system_service = self.application.system_service
+        value = system_service.evaluate(
+            vba_code, 0, vba_function_name, [self.com_object]
+        )
+
+        # we don't return value directly as CATIA returns for example
+        # "(-15.0, 30.0, -15.0, 30.0, None)" I don't know what the additional
+        # value None at the end represents.
+        return value[0], value[1], value[2], value[3]
 
     def un_aligned_with_reference_view(self) -> None:
         """
