@@ -514,7 +514,7 @@ class AxisSystem(AnyObject):
 
         self.axis_system.ZAxisType = value
 
-    def get_euler_angles(self, o_first_angle: Angle, o_second_angle: Angle, third_angle: Angle) -> None:
+    def get_euler_angles(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -534,25 +534,20 @@ class AxisSystem(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.axis_system.GetEulerAngles(o_first_angle.com_object, o_second_angle.com_object,
-                                               third_angle.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_euler_angles'
-        # # vba_code = """
-        # # Public Function get_euler_angles(axis_system)
-        # #     Dim oFirstAngle (2)
-        # #     axis_system.GetEulerAngles oFirstAngle
-        # #     get_euler_angles = oFirstAngle
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_euler_angles'
+        vba_code = """
+        Public Function get_euler_angles(axis_system)
+            Dim oFirstAngle (2)
+            axis_system.GetEulerAngles oFirstAngle
+            get_euler_angles = oFirstAngle
+        End Function
+        """
 
-    def get_origin(self, o_origin: tuple) -> None:
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_origin(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -581,24 +576,20 @@ class AxisSystem(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.axis_system.GetOrigin(o_origin)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_origin'
-        # # vba_code = """
-        # # Public Function get_origin(axis_system)
-        # #     Dim oOrigin (2)
-        # #     axis_system.GetOrigin oOrigin
-        # #     get_origin = oOrigin
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_origin'
+        vba_code = """
+        Public Function get_origin(axis_system)
+            Dim oOrigin (2)
+            axis_system.GetOrigin oOrigin
+            get_origin = oOrigin
+        End Function
+        """
 
-    def get_vectors(self, o_vector_x: tuple, o_vector_y: tuple) -> None:
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_vectors(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -635,24 +626,20 @@ class AxisSystem(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.axis_system.GetVectors(o_vector_x, o_vector_y)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_vectors'
-        # # vba_code = """
-        # # Public Function get_vectors(axis_system)
-        # #     Dim oVectorX (2)
-        # #     axis_system.GetVectors oVectorX
-        # #     get_vectors = oVectorX
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_vectors'
+        vba_code = """
+        Public Function get_vectors(axis_system)
+            Dim oVectorX (2)
+            axis_system.GetVectors oVectorX
+            get_vectors = oVectorX
+        End Function
+        """
 
-    def get_x_axis(self, o_x_axis: tuple) -> None:
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_x_axis(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -681,24 +668,20 @@ class AxisSystem(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.axis_system.GetXAxis(o_x_axis)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_x_axis'
-        # # vba_code = """
-        # # Public Function get_x_axis(axis_system)
-        # #     Dim oXAxis (2)
-        # #     axis_system.GetXAxis oXAxis
-        # #     get_x_axis = oXAxis
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_x_axis'
+        vba_code = """
+        Public Function get_x_axis(axis_system)
+            Dim oXAxis (2)
+            axis_system.GetXAxis oXAxis
+            get_x_axis = oXAxis
+        End Function
+        """
 
-    def get_y_axis(self, o_y_axis: tuple) -> None:
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_y_axis(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -727,24 +710,20 @@ class AxisSystem(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.axis_system.GetYAxis(o_y_axis)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_y_axis'
-        # # vba_code = """
-        # # Public Function get_y_axis(axis_system)
-        # #     Dim oYAxis (2)
-        # #     axis_system.GetYAxis oYAxis
-        # #     get_y_axis = oYAxis
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_y_axis'
+        vba_code = """
+        Public Function get_y_axis(axis_system)
+            Dim oYAxis (2)
+            axis_system.GetYAxis oYAxis
+            get_y_axis = oYAxis
+        End Function
+        """
 
-    def get_z_axis(self, o_z_axis: tuple) -> None:
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def get_z_axis(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -773,22 +752,18 @@ class AxisSystem(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.axis_system.GetZAxis(o_z_axis)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_z_axis'
-        # # vba_code = """
-        # # Public Function get_z_axis(axis_system)
-        # #     Dim oZAxis (2)
-        # #     axis_system.GetZAxis oZAxis
-        # #     get_z_axis = oZAxis
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_z_axis'
+        vba_code = """
+        Public Function get_z_axis(axis_system)
+            Dim oZAxis (2)
+            axis_system.GetZAxis oZAxis
+            get_z_axis = oZAxis
+        End Function
+        """
+
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def put_origin(self, i_origin: tuple) -> None:
         """
